@@ -70,8 +70,10 @@
 /* external and forward functions definitions */
 #if NeedFunctionPrototypes
   extern void realize_dialog(Widget, Widget, XtGrabKind, XtEventHandler, XtPointer);
+  extern void child_died(void);
 #else
   extern void realize_dialog();
+  extern void child_died();
 #endif
 
 typedef struct _ProcessEnv
@@ -100,7 +102,7 @@ public int openMasterAndSlave(master, slave)
      *
      * + returns 0 if it succeeds, 1 otherwise.
      */
-#ifndef ibm
+#if !defined(ibm) && !defined(SVR4)
     int  i; 
     char c;
 
@@ -120,6 +122,33 @@ public int openMasterAndSlave(master, slave)
 	    }
 	}
     }
+#else
+#if defined(SVR4) /* System V R4 multiplexer device */
+    extern char *ptsname(int);
+
+#ifdef DEBUG
+    fprintf(stderr,"Trying to get pty (SVR4)\n");
+#endif
+    if ((*master = open("/dev/ptmx", O_RDWR)) >= 0)
+    {
+	/* disable SIGCHLD, because grantpt() calls a setuid program to
+	   change the slave tty ownership */
+	signal(SIGCHLD, SIG_DFL); /* SVR4 is POSIX, so we use SIGCHLD */
+        grantpt (*master);
+	signal(SIGCHLD, child_died);
+        unlockpt (*master);
+#ifdef DEBUG
+        fprintf(stderr,"name of slave tty: %s\n", ptsname(*master));
+#endif
+	if ((*slave = open(ptsname(*master), O_RDWR)) >= 0)
+	{
+            return 0;
+        }
+        else perror("Error opening tty slave");
+
+    }
+    else perror("Error opening tty master");
+
 #else
     if ((*master = open("/dev/ptc", O_RDWR)) != -1)
     {
@@ -127,7 +156,9 @@ public int openMasterAndSlave(master, slave)
 	{
 	    return 0;
 	}
+	else close(*master);
     }
+#endif
 #endif
     fprintf(stderr, "Xdtm: all ptys in use\n");
     return 1;
@@ -492,6 +523,7 @@ public void AttachProcessToTermWindow(father, fullname, fp, fd, pid)
     
     i = 0;
     XtSetArg(arglist[i], XtNwidth,   width); i++;
+    XtSetValues(termWindowLabel, arglist, i);
     XtSetArg(arglist[i], XtNheight, height); i++;
     XtSetValues(termWindowText, arglist, i);
 
