@@ -70,16 +70,31 @@ static XtResource xedwFormConstraintResources[] = {
 };
 #undef Offset
 
+
+#if NeedFunctionPrototypes
+static void ClassInitialize(void);
+static void ClassPartInitialize(WidgetClass);
+static void Initialize(Widget, Widget, ArgList, Cardinal *);
+static void Resize(Widget);
+static void ConstraintInitialize(Widget, Widget, ArgList, Cardinal *);
+static Boolean SetValues(Widget, Widget, Widget, ArgList, Cardinal *);
+static Boolean ConstraintSetValues(Widget, Widget, Widget, ArgList, Cardinal *);
+static XtGeometryResult GeometryManager(Widget, XtWidgetGeometry *, XtWidgetGeometry *);
+static XtGeometryResult PreferredGeometry(Widget, XtWidgetGeometry *, XtWidgetGeometry *);
+static void ChangeManaged(Widget);
+static Boolean Layout(XedwFormWidget, Dimension, Dimension);
+static void LayoutChild(Widget);
+void XedwFormDoLayout(Widget, Boolean);
+#else
 static void ClassInitialize(), ClassPartInitialize(), Initialize(), Resize();
 static void ConstraintInitialize();
 static Boolean SetValues(), ConstraintSetValues();
 static XtGeometryResult GeometryManager(), PreferredGeometry();
 static void ChangeManaged();
-static Boolean Layout(
-#if NeedFunctionPrototypes
-    XedwFormWidget, Dimension, Dimension
+static Boolean Layout();
+static void LayoutChild();
+void XedwFormDoLayout();
 #endif
-);
 
 XedwFormClassRec xedwFormClassRec = {
   { /* core_class fields */
@@ -155,10 +170,14 @@ static XrmQuark XtQChainLeft, XtQChainRight, XtQChainTop,
   return; \
 }
 
+#if NeedFunctionPrototypes
+static void _CvtStringToEdgeType(XrmValuePtr args, Cardinal *num_args, XrmValuePtr fromVal, XrmValuePtr toVal)
+#else
 static void _CvtStringToEdgeType(args, num_args, fromVal, toVal)
 XrmValuePtr args;
 Cardinal *num_args;
 XrmValuePtr fromVal, toVal;
+#endif
 {
   static XtEdgeType edgeType;
   XrmQuark q;
@@ -191,7 +210,11 @@ XrmValuePtr fromVal, toVal;
   toVal->size = 0;
 }
 
+#if NeedFunctionPrototypes
+static void ClassInitialize(void)
+#else
 static void ClassInitialize()
+#endif
 {
   static XtConvertArgRec parentCvtArgs[] = {
     {XtBaseOffset, (caddr_t)XtOffset(Widget, core.parent), sizeof(Widget)}
@@ -208,8 +231,12 @@ static void ClassInitialize()
 		 parentCvtArgs, XtNumber(parentCvtArgs) );
 }
 
+#if NeedFunctionPrototypes
+static void ClassPartInitialize(WidgetClass class)
+#else
 static void ClassPartInitialize(class)
 WidgetClass class;
+#endif
 {
   register XedwFormWidgetClass c = (XedwFormWidgetClass)class;
 
@@ -218,8 +245,14 @@ WidgetClass class;
 }
 
 
+#if NeedFunctionPrototypes
+static void Initialize(Widget request, Widget new, ArgList args, Cardinal *num_args)
+#else
 static void Initialize(request, new)
 Widget request, new;
+ArgList args;
+Cardinal *num_args;
+#endif
 {
   XedwFormWidget fw = (XedwFormWidget)new;
 
@@ -231,8 +264,12 @@ Widget request, new;
 }
 
 
+#if NeedFunctionPrototypes
+static void RefigureLocations(XedwFormWidget w)
+#else
 static void RefigureLocations(w)
 XedwFormWidget w;
+#endif
 {
   if (w->xedwForm.no_refigure) {
     w->xedwForm.needs_relayout = True;
@@ -243,15 +280,18 @@ XedwFormWidget w;
   }
 }
 
+#if NeedFunctionPrototypes
+static Boolean Layout(XedwFormWidget fw, Dimension width, Dimension height)
+#else
 static Boolean Layout(fw, width, height)
 XedwFormWidget fw;
 Dimension width, height;
+#endif
 {
   int num_children = fw->composite.num_children;
   WidgetList children = fw->composite.children;
   Widget *childP;
   Position maxx, maxy;
-  static void LayoutChild();
   Boolean ret_val;
   
   for (childP = children; childP - children < num_children; childP++) {
@@ -321,8 +361,12 @@ Dimension width, height;
 }
 
 
+#if NeedFunctionPrototypes
+static void LayoutChild(Widget w)
+#else
 static void LayoutChild(w)
 Widget w;
+#endif
 {
   XedwFormConstraints xedwForm = (XedwFormConstraints)w->core.constraints;
   Position x, y;
@@ -376,10 +420,14 @@ Widget w;
 }
 
 
+#if NeedFunctionPrototypes
+static Position TransformCoord(Position loc, Dimension old, Dimension new, XawEdgeType type)
+#else
 static Position TransformCoord(loc, old, new, type)
 Position loc;
 Dimension old,new;
 XtEdgeType type;
+#endif
 {
   if (type == XtRubber) {
     if ( ((int) old) > 0)
@@ -394,8 +442,12 @@ XtEdgeType type;
 }
 
 
+#if NeedFunctionPrototypes
+static void Resize(Widget w)
+#else
 static void Resize(w)
 Widget w;
+#endif
 {
   XedwFormWidget fw = (XedwFormWidget)w;
   WidgetList children = fw->composite.children;
@@ -444,9 +496,13 @@ Widget w;
 }
 
 
+#if NeedFunctionPrototypes
+static XtGeometryResult GeometryManager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
+#else
 static XtGeometryResult GeometryManager(w, request, reply)
 Widget w;
 XtWidgetGeometry *request, *reply;
+#endif
 {
   XedwFormConstraints xedwForm = (XedwFormConstraints)w->core.constraints;
   XtWidgetGeometry allowed;
@@ -479,15 +535,27 @@ XtWidgetGeometry *request, *reply;
 
 
 
+#if NeedFunctionPrototypes
+static Boolean SetValues(Widget current, Widget request, Widget new, ArgList args, Cardinal *num_args)
+#else
 static Boolean SetValues(current, request, new)
 Widget current, request, new;
+ArgList args;
+Cardinal *num_args;
+#endif
 {
   return( FALSE );
 }
 
 
+#if NeedFunctionPrototypes
+static void ConstraintInitialize(Widget request, Widget new, ArgList args, Cardinal *num_args)
+#else
 static void ConstraintInitialize(request, new)
 Widget request, new;
+ArgList args;
+Cardinal *num_args;
+#endif
 {
   XedwFormConstraints xedwForm = (XedwFormConstraints)new->core.constraints;
   XedwFormWidget fw = (XedwFormWidget)new->core.parent;
@@ -502,14 +570,24 @@ Widget request, new;
     xedwForm->xedwForm.dy = fw->xedwForm.default_spacing;
 }
 
+#if NeedFunctionPrototypes
+static Boolean ConstraintSetValues(Widget current, Widget request, Widget new, ArgList args, Cardinal *num_args)
+#else
 static Boolean ConstraintSetValues(current, request, new)
 Widget current, request, new;
+ArgList args;
+Cardinal *num_args;
+#endif
 {
   return( FALSE );
 }
 
+#if NeedFunctionPrototypes
+static void ChangeManaged(Widget w)
+#else
 static void ChangeManaged(w)
 Widget w;
+#endif
 {
   XedwFormWidget fw = (XedwFormWidget)w;
   XedwFormConstraints xedwForm;
@@ -536,9 +614,13 @@ Widget w;
 }
 
 
+#if NeedFunctionPrototypes
+static XtGeometryResult PreferredGeometry(Widget widget, XtWidgetGeometry *request, XtWidgetGeometry *reply)
+#else
 static XtGeometryResult PreferredGeometry(widget, request, reply)
 Widget widget;
 XtWidgetGeometry *request, *reply;
+#endif
 {
   XedwFormWidget w = (XedwFormWidget)widget;
 
@@ -567,9 +649,13 @@ XtWidgetGeometry *request, *reply;
  * Set or reset figuring (ignored if not realized)
  */
 
+#if NeedFunctionPrototypes
+void XedwFormDoLayout(Widget w, Boolean doit)
+#else
 void XedwFormDoLayout(w, doit)
 Widget w;
 Boolean doit;
+#endif
 {
   register XedwFormWidget fw = (XedwFormWidget)w;
 
