@@ -109,7 +109,7 @@ static XtResource resources[] = {
 };
 
 #if NeedFunctionPrototypes
-static void             Initialize   (Widget, Widget);
+static void             Initialize   (Widget, Widget, ArgList, Cardinal*);
 static void             ChangeSize   (Widget, Dimension, Dimension);
 static void             Resize       (Widget);
 static void             Redisplay    (Widget, XEvent*, Region);
@@ -123,6 +123,7 @@ static void             Notify       (Widget, XEvent*, String*, Cardinal*),
 static Boolean 		IsHighlighted(Widget, int);
 static void		AddNode	     (Widget, int);
 static void		RemoveNode   (Widget, int);
+static void             selection_set_buffer(Widget, String);
 #else
 static void             Initialize   ();
 static void             ChangeSize   ();
@@ -138,6 +139,7 @@ static void             Notify       (),
 static Boolean 		IsHighlighted();
 static void		AddNode	     ();
 static void		RemoveNode   ();
+static void             selection_set_buffer();
 #endif
 
 static XtActionsRec actions[] = {
@@ -207,8 +209,12 @@ static GC maskgc = (GC) NULL;
  *
  ****************************************************************/
 
+#if NeedFunctionPrototypes
+static void GetGCs(Widget w)
+#else
 static void GetGCs(w)
 Widget w;
+#endif
 {
 
   XGCValues   values;
@@ -234,11 +240,12 @@ Widget w;
   values.foreground   = ilw->xedwList.foreground;
   values.background   = ilw->core.background_pixel; 
   values.font         = ilw->xedwList.font->fid;
-  ilw->xedwList.normgc = XtGetGC(w, (unsigned) GCBackground | GCForeground | GCFont, &values);
+  values.graphics_exposures = False;
+  ilw->xedwList.normgc = XtGetGC(w, (unsigned) GCBackground | GCForeground | GCFont | GCGraphicsExposures, &values);
 
   values.foreground   = ilw->core.background_pixel; 
   values.background   = ilw->xedwList.foreground;
-  ilw->xedwList.revgc = XtGetGC(w, (unsigned) GCBackground | GCForeground | GCFont, &values);
+  ilw->xedwList.revgc = XtGetGC(w, (unsigned) GCBackground | GCForeground | GCFont | GCGraphicsExposures, &values);
 
   values.tile       = XmuCreateStippledPixmap(XtScreen(w),
 					      ilw->xedwList.foreground,
@@ -257,9 +264,13 @@ Widget w;
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+static void ResetXedwList(Widget w, Boolean changex, Boolean changey)
+#else
 static void ResetXedwList(w, changex, changey)
 Widget w;
 Boolean changex, changey;
+#endif
 {
   XedwListWidget ilw = (XedwListWidget) w;
   Dimension width = w->core.width;
@@ -311,9 +322,13 @@ Boolean changex, changey;
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+static void ChangeSize(Widget w, Dimension width, Dimension height)
+#else
 static void ChangeSize(w, width, height)
 Widget w;
 Dimension width, height;
+#endif
 {
   XtWidgetGeometry request, reply;
 
@@ -367,19 +382,25 @@ Dimension width, height;
  *  Returns: none
  */
 
-static void Initialize(junk, new)
+#if NeedFunctionPrototypes
+static void Initialize(Widget junk, Widget new, ArgList args, Cardinal *num_args)
+#else
+static void Initialize(junk, new, args, num_args)
 Widget junk, new;
+ArgList args;
+Cardinal *num_args;
+#endif
 {
   XedwListWidget ilw = (XedwListWidget) new;
-#ifdef XPM
   Widget w = junk;
-  XpmAttributes pixmapAttrs;
-  int pixmapReadStatus = XpmSuccess;
-
   Display *dpy = XtDisplay(w);
   Screen *scr = XtScreen(w);
   Window rootWindow = XRootWindowOfScreen(scr);
 
+#ifdef XPM
+  XpmAttributes pixmapAttrs;
+  int pixmapReadStatus = XpmSuccess;
+
   pixmapAttrs.visual       = DefaultVisual(dpy, DefaultScreen(dpy));
   pixmapAttrs.colormap     = DefaultColormap(dpy, DefaultScreen(dpy));
   pixmapAttrs.depth        = DefaultDepthOfScreen(scr);
@@ -431,8 +452,8 @@ Widget junk, new;
 #else
   defaultIconPixmap = 
     XCreateBitmapFromData(
-        XtDisplay( junk ),
-	XtWindow( junk ),
+        dpy,
+	rootWindow,
 	default_bits, default_width, default_height);
   defaultIconPixmapMask = NULL;
 #endif
@@ -446,9 +467,13 @@ Widget junk, new;
  *  Returns: the item number.
  */
 
+#if NeedFunctionPrototypes
+static int CvtToItem(Widget w, int xloc, int yloc, int *item)
+#else
 static int CvtToItem(w, xloc, yloc, item)
 Widget w;
 int xloc, yloc, *item;
+#endif
 {
   int one, another;
   XedwListWidget ilw = (XedwListWidget) w;
@@ -492,10 +517,14 @@ int xloc, yloc, *item;
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+static void FindCornerItems(Widget w, XEvent *event, int *ul_ret, int *lr_ret)
+#else
 static void FindCornerItems(w, event, ul_ret, lr_ret)
 Widget w;
 XEvent *event;
 int *ul_ret, *lr_ret;
+#endif
 {
   int xloc, yloc;
   
@@ -515,9 +544,13 @@ int *ul_ret, *lr_ret;
  *  Returns: TRUE if the item passed is in the given rectangle.
  */
 
+#if NeedFunctionPrototypes
+static int ItemInRectangle(Widget w, int ul, int lr, int item)
+#else
 static int ItemInRectangle(w, ul, lr, item)
 Widget w;
 int ul, lr, item;
+#endif
 {
   XedwListWidget ilw = (XedwListWidget) w;
   register int mod_item;
@@ -545,11 +578,15 @@ int ul, lr, item;
  *  Returns:
  */
 
+#if NeedFunctionPrototypes
+static void HighlightBackground(Widget w, Drawable drawable, int x, int y, int item, GC gc)
+#else
 static void HighlightBackground(w, drawable, x, y, item, gc)
 Widget w;
 Drawable drawable;
 int x,y,item;
 GC gc;
+#endif
 {
   XedwListWidget ilw = (XedwListWidget) w;
   int hl_x, hl_y, width, height;
@@ -576,10 +613,14 @@ GC gc;
  *      NOTE: no action taken on an unrealized widget.
  */
 
+#if NeedFunctionPrototypes
+static void PaintItemName(Widget w, Drawable drawable, int item, int operation)
+#else
 static void PaintItemName(w, drawable, item, operation)
 Widget w;
 Drawable drawable;
 int item, operation;
+#endif
 {
   char * str;
   GC gc;
@@ -616,11 +657,10 @@ int item, operation;
 
   if (DefaultDepthOfScreen(XtScreen(ilw)) == 1) {
     /* Monochrome */
-    if ((BlackPixelOfScreen(XtScreen(ilw))) == 1 &&
-	ilw->core.background_pixel == WhitePixelOfScreen(XtScreen(ilw))) { 
+    if (ilw->core.background_pixel == WhitePixelOfScreen(XtScreen(ilw))) { 
       normalmode = GXcopy;
       inversemode = GXcopyInverted;
-    } else {				/* On a machine with black = 0 OR  */
+    } else {
       normalmode = GXcopyInverted;	/* reverse video has been selected */
       inversemode = GXcopy;
     }
@@ -747,17 +787,19 @@ int item, operation;
  *  Returns:
  */
 
+#if NeedFunctionPrototypes
+static void Redisplay(Widget w, XEvent *event, Region junk)
+#else
 static void Redisplay(w, event, junk)
 Widget w;
 XEvent *event;
 Region junk;
+#endif
 {
   int item;           /* an item to work with. */
   int ul_item, lr_item;       /* corners of items we need to paint. */
   XedwListWidget ilw = (XedwListWidget) w;
   Display *dpy = XtDisplay(w);
-  Pixmap backStore= (Pixmap) NULL;
-  Boolean use_backstore = True;
   GC gc = ilw->xedwList.normgc;
 
   if (event == NULL) {    /* repaint all. */
@@ -768,34 +810,14 @@ Region junk;
   else
     FindCornerItems(w, event, &ul_item, &lr_item);
 
-  if (!(backStore = XCreatePixmap(dpy, XtWindow(w),
-				  w->core.width,
-				  w->core.height,
-				  DefaultDepth(dpy, XDefaultScreen(dpy))))) {
-      backStore = XtWindow(w);
-      use_backstore = False;
-    } 
-  if (use_backstore) {
-      XSetFunction(dpy, gc, GXcopy);
-      XSetGraphicsExposures(dpy, gc, False);
-      XCopyArea(dpy, XtWindow(w), backStore, gc, 0, 0,
-		w->core.width, w->core.height, 0, 0);
-  }
-
   ilw->xedwList.highlight = NO_HIGHLIGHT;
   for (item = ul_item; (item <= lr_item && item < ilw->xedwList.nitems) ; item++)
     if (ItemInRectangle(w, ul_item, lr_item, item))
       if (IsHighlighted(w, item))
-	PaintItemName(w, backStore, item, XedwOn);
+	PaintItemName(w, XtWindow(w), item, XedwOn);
       else
-	PaintItemName(w, backStore, item, XedwOff);
+	PaintItemName(w, XtWindow(w), item, XedwOff);
 
-  if (use_backstore) {
-      XCopyArea(dpy, backStore, XtWindow(w), gc, 0, 0,
-		w->core.width, w->core.height, 0, 0);
-      XSetGraphicsExposures(dpy, gc, True);
-      XFreePixmap(dpy, backStore);
-  }
 }
 
 /*  Function Name: PreferredGeom
@@ -807,9 +829,13 @@ Region junk;
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+static XtGeometryResult PreferredGeom(Widget w, XtWidgetGeometry *intended, XtWidgetGeometry *requested)
+#else
 static XtGeometryResult PreferredGeom(w, intended, requested)
 Widget w;
 XtWidgetGeometry *intended, *requested;
+#endif
 {
   Dimension new_width, new_height;
   Boolean change, width_req, height_req;
@@ -855,8 +881,12 @@ XtWidgetGeometry *intended, *requested;
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+static void Resize(Widget w)
+#else
 static void Resize(w)
 Widget w;
+#endif
 {
   Dimension width, height;
 
@@ -880,10 +910,14 @@ Widget w;
  *  Returns: TRUE if width or height have been changed.
  */
 
+#if NeedFunctionPrototypes
+static Boolean Layout(Widget w, Boolean xfree, Boolean yfree, Dimension *width, Dimension *height)
+#else
 static Boolean Layout(w, xfree, yfree, width, height)
 Widget w;
 Boolean xfree, yfree;
 Dimension *width, *height;
+#endif
 {
   XedwListWidget ilw = (XedwListWidget) w;
   Boolean change = FALSE;
@@ -971,11 +1005,15 @@ Dimension *width, *height;
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+static void Notify(Widget w, XEvent *event, String *params, Cardinal *num_params)
+#else
 static void Notify(w, event, params, num_params)
 Widget w;
 XEvent *event;
 String *params;
 Cardinal *num_params;
+#endif
 {
   XedwListWidget ilw = ( XedwListWidget ) w;
   int item, item_len;
@@ -999,11 +1037,6 @@ Cardinal *num_params;
     {
       XStoreBytes(XtDisplay(w), ilw->xedwList.xedwList[item]->string, item_len);
       {
-#if NeedFunctionPrototypes
-	static void selection_set_buffer(Widget, String);
-#else
-	static void selection_set_buffer();
-#endif	
 	
 	selection_set_buffer(w,ilw->xedwList.xedwList[item]->string);
       }
@@ -1027,11 +1060,15 @@ Cardinal *num_params;
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+static void Unset(Widget w, XEvent *event, String *params, Cardinal *num_params)
+#else
 static void Unset(w, event, params, num_params)
 Widget w;
 XEvent *event;
 String *params;
 Cardinal *num_params;
+#endif
 {
   XedwListUnhighlight(w, XedwAll);
 }
@@ -1044,11 +1081,15 @@ Cardinal *num_params;
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+static void Set(Widget w, XEvent *event, String *params, Cardinal *num_params)
+#else
 static void Set(w, event, params, num_params)
 Widget w;
 XEvent *event;
 String *params;
 Cardinal *num_params;
+#endif
 {
   int item;
   XedwListWidget ilw = (XedwListWidget) w;
@@ -1072,11 +1113,15 @@ Cardinal *num_params;
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+static void MultipleSet(Widget w, XEvent *event, String *params, Cardinal *num_params)
+#else
 static void MultipleSet(w, event, params, num_params)
 Widget w;
 XEvent *event;
 String *params;
 Cardinal *num_params;
+#endif
 {
   int item;
   XedwListWidget ilw = (XedwListWidget) w;
@@ -1097,9 +1142,13 @@ Cardinal *num_params;
 /* 
  * Return state of a list item 
  */
+#if NeedFunctionPrototypes
+static Boolean IsHighlighted(Widget w, int item)
+#else
 static Boolean IsHighlighted(w, item)
 Widget w;
 int item;
+#endif
 {
   XedwListWidget ilw = (XedwListWidget) w;
   LinkedList *list = ilw->xedwList.is_highlighted;
@@ -1120,10 +1169,14 @@ int item;
  * Set specified arguments into widget
  */
 
+#if NeedFunctionPrototypes
+static Boolean SetValues(Widget current, Widget request, Widget new, ArgList args, Cardinal *num_args)
+#else
 static Boolean SetValues(current, request, new, args, num_args)
 Widget current, request, new;
 ArgList args;
 Cardinal *num_args;
+#endif
 {
   XedwListWidget cl = (XedwListWidget) current;
   XedwListWidget rl = (XedwListWidget) request;
@@ -1202,11 +1255,10 @@ Cardinal *num_args;
  *  Arguments: list - the XedwListReturnStruct list.
  *  Returns: none.
  */
-void XedwListFreeCurrent(
 #if NeedFunctionPrototypes
-			 XedwListReturnStruct *list)
+void XedwListFreeCurrent(XedwListReturnStruct *list)
 #else
-			 list)
+void XedwListFreeCurrent(list)
      XedwListReturnStruct *list;
 #endif /* NeedFunctionPrototypes */
 {
@@ -1240,11 +1292,15 @@ void XedwListFreeCurrent(
  *                 If nitems is <= 0 then the xedwList needs to be NULL terminated.
  */
 
+#if NeedFunctionPrototypes
+void XedwListChange(Widget w, XedwList **xedwList, int nitems, int longest, Boolean resize_it)
+#else
 void XedwListChange(w, xedwList, nitems, longest, resize_it)
      Widget w;
      XedwList **xedwList;
      int nitems, longest;
      Boolean resize_it;
+#endif
 {
   XedwListWidget ilw = (XedwListWidget) w;
 
@@ -1269,9 +1325,13 @@ void XedwListChange(w, xedwList, nitems, longest, resize_it)
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+void XedwListUnhighlight(Widget w, int item)
+#else
 void XedwListUnhighlight(w, item)
      Widget w;
      int item;
+#endif
 {
   XedwListWidget ilw = ( XedwListWidget ) w;
   LinkedList *list = ilw->xedwList.is_highlighted;
@@ -1304,9 +1364,13 @@ void XedwListUnhighlight(w, item)
  *  Returns: none.
  */
 
+#if NeedFunctionPrototypes
+void XedwListHighlight(Widget w, int item)
+#else
 void XedwListHighlight(w, item)
      Widget w;
      int item;
+#endif
 {
   XedwListWidget ilw = ( XedwListWidget ) w;
   int n;
@@ -1338,13 +1402,17 @@ void XedwListHighlight(w, item)
 static String selection_value;
 static Atom selection_atom=0;
 
+#if NeedFunctionPrototypes
+static Boolean ConvertSelection(Widget w, Atom *selection, Atom *target, Atom *type, XtPointer *value, unsigned long *length, int *format)
+#else
 static Boolean ConvertSelection(w, selection, target,
                                 type, value, length, format)
      Widget w;
      Atom *selection, *target, *type;
-     caddr_t *value;
+     XtPointer *value;
      unsigned long *length;
      int *format;
+#endif
 {
     Display* d = XtDisplay(w);
     XSelectionRequestEvent* req =
@@ -1395,24 +1463,32 @@ static Boolean ConvertSelection(w, selection, target,
         return True;
     }
     if (XmuConvertStandardSelection(w, req->time, selection, target, type,
-                                    value, length, format))
+                                    (caddr_t *)value, length, format))
         return True;
 
     /* else */
     return False;
 }
 
+#if NeedFunctionPrototypes
+static void LoseSelection(Widget w, Atom *selection)
+#else
 static void LoseSelection(w, selection)
     Widget w;
     Atom *selection;
+#endif
 {
     XtFree((char *)selection_value );
     selection_value = NULL;
 }
 
-static void selection_set_buffer(w,string)
+#if NeedFunctionPrototypes
+static void selection_set_buffer(Widget w, String string)
+#else
+static void selection_set_buffer(w, string)
     Widget w;
     String string;
+#endif
 {
     static char * name="PRIMARY";
     if (selection_atom==0)
@@ -1422,7 +1498,7 @@ static void selection_set_buffer(w,string)
     selection_value=XtNewString(string);
     XtOwnSelection(w, selection_atom,
                            XtLastTimestampProcessed(XtDisplay(w)),
-                           ConvertSelection, LoseSelection, NULL);
+                            ConvertSelection, LoseSelection, NULL);
 }
 
 
@@ -1432,8 +1508,12 @@ static void selection_set_buffer(w,string)
  *  Returns: the info about the currently highlighted object.
  */
 
+#if NeedFunctionPrototypes
+XedwListReturnStruct *XedwListShowCurrent(Widget w)
+#else
 XedwListReturnStruct *XedwListShowCurrent(w)
      Widget w;
+#endif
 {
   XedwListWidget ilw = ( XedwListWidget ) w;
   LinkedList *hl = ilw->xedwList.is_highlighted;
@@ -1457,8 +1537,12 @@ XedwListReturnStruct *XedwListShowCurrent(w)
   return ret_val;
 }
 
+#if NeedFunctionPrototypes
+Boolean XedwListSelection(Widget w)
+#else
 Boolean XedwListSelection(w)
 Widget w;
+#endif
 {
   XedwListWidget ilw = ( XedwListWidget ) w;
   LinkedList *hl = ilw->xedwList.is_highlighted;
@@ -1472,9 +1556,13 @@ Widget w;
 
 /* AddNode to LinkedList of highlighted items
  */
+#if NeedFunctionPrototypes
+static void AddNode(Widget w, int item)
+#else
 static void AddNode(w, item)
 Widget w;
 int item;
+#endif
 {
   XedwListWidget ilw = ( XedwListWidget ) w;
   LinkedList *list = ilw->xedwList.is_highlighted;
@@ -1492,9 +1580,13 @@ int item;
 }
   
 
+#if NeedFunctionPrototypes
+static void RemoveNode(Widget w, int item)
+#else
 static void RemoveNode(w, item)
 Widget w;
 int item;
+#endif
 {
   XedwListWidget ilw = ( XedwListWidget ) w;
   LinkedList *list = ilw->xedwList.is_highlighted;
