@@ -38,11 +38,11 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <signal.h>
+#include <fcntl.h>
 #include <sys/types.h>		/* For opening and closing file descriptors */
 #include <sys/stat.h>		/* For opening and closing file descriptors */
 #include <sys/wait.h>
 #include <sys/time.h>
-#include <sys/resource.h>
 #ifdef USE_TERMIOS
 #include <termios.h>
 #else
@@ -63,6 +63,11 @@
 #include <sys/file.h>		/* For access(2) */
 #endif
 
+#ifdef linux
+#define FAPPEND O_APPEND
+#define FNDELAY O_NDELAY
+#endif
+
 /* external and forward functions definitions */
 #if NeedFunctionPrototypes
   extern void AttachProcessToTermWindow(Widget, String, FILE*, int, int);
@@ -72,7 +77,8 @@
   extern void changestate(Boolean);
   public void child_died(void);
   extern Cardinal count_chr(String, char);
-  private void decrement_counter(int pid);
+  private void checkMissedPid(void);
+  private Boolean decrement_counter(int pid);
   extern void destroy_button_dialog(void);
   extern Boolean directoryManagerNewDirectory(String);
   public int  execute(String, String, String, Boolean, AppProgram *);
@@ -82,7 +88,7 @@
   extern void ioerr_dialog(int errno);
   extern int openMasterAndSlave(int *, int *);
   void pl_select_made(Widget, XtPointer, XtPointer);
-  private int plistcmp(XedwList **, XedwList **);
+  private int plistcmp(const void *, const void *);
   void popdown_kill(Widget, XtPointer, XtPointer);
   private void popup_kill();
   public void popup_process_list(void);
@@ -106,7 +112,8 @@
   extern void changestate();
   public void child_died();
   extern Cardinal count_chr();
-  private void decrement_counter();
+  private void checkMissedPid();
+  private Boolean decrement_counter();
   extern void destroy_button_dialog();
   extern Boolean directoryManagerNewDirectory();
   public int  execute();
@@ -150,6 +157,8 @@
 #define DEBUG 1
 */
 
+#define maxPids 10
+private int            missedPid[maxPids];
 public  ProcessList   *process_list;
 private XedwList     **proclist;
 private Boolean        proclist_visible = FALSE;
@@ -321,7 +330,7 @@ Widget topForm;
 	    NULL ) ;
 
   /* Create the Pixmap for the trash button */
-  trash = XCreateBitmapFromData(XtDisplay(topForm),
+   trash = XCreateBitmapFromData(XtDisplay(topForm),
 				RootWindowOfScreen(XtScreen(topForm)),
 				trash_bits,
 				trash_width, trash_height);
@@ -982,9 +991,9 @@ XtPointer call_data;
     }
     copystring = (String) XtRealloc (copystring, sizeof(char) *
 				     (strlen(copystring) +
-				      dstlen + 20));
+				      dstlen + 70));
 
-    sprintf(copystring, "%s)|(cd %s;tar xmf -)'", copystring, dstdir);
+    sprintf(copystring, "%s)|(cd %s;f=/tmp/$$;tar xmf - 2>$f;[ ! -s $f ];s=$?;rm $f;exit $s)'", copystring, dstdir);
     if ((status = execute(NULL, "sh", copystring, True, NULL)) != 0) {
       if (count == 1)
 	alert_dialog("Sorry, that file could","not be copied", NULL);
@@ -1041,7 +1050,7 @@ XtPointer call_data;
      */
     srclen = strlen(srcdir);
     dstlen = strlen(dstdir);
-    movestring = XtNewString("sh -c '(cd");
+    movestring = XtNewString("sh -c 'cd");
     rmstring = XtNewString("rm -rf");
     movestring = (String) XtRealloc (movestring, sizeof(char) *
 				     (strlen(movestring) + srclen + 12));
@@ -1061,9 +1070,10 @@ XtPointer call_data;
     }
     movestring = (String) XtRealloc (movestring, sizeof(char) *
 				     (strlen(movestring) +
-				      dstlen + 20));
+				      dstlen + 70));
+
+    sprintf(movestring, "%s|(cd %s;f=/tmp/$$;tar xf - 2>$f;[ ! -s $f ];s=$?;rm $f;exit $s)'", movestring, dstdir);
 
-    sprintf(movestring, "%s)|(cd %s;tar xf -)'", movestring, dstdir);
     if ((status = execute(NULL, "sh", movestring, True, NULL)) != 0) {
       if (count == 1)
 	alert_dialog("Sorry, that file could", "not be moved", NULL);
@@ -1136,23 +1146,25 @@ XtPointer crap;
   }
   appman_selection = selection;
 
-  XtVaSetValues(
-      appManagerButton,
-          XtNlabel, appselections[appman_selection]->name,
-	  NULL ) ;
+  if (appselections[appman_selection] != NULL) {
+      XtVaSetValues(
+		    appManagerButton,
+		    XtNlabel, appselections[appman_selection]->name,
+		    NULL ) ;
 
-  /* Change contents of AppManager to that of the new selection*/
-  old_list = appselections[appman_selection]->list;
-  max = appselections[appman_selection]->number;
-  list = (XedwList **) XtMalloc((max+1) * sizeof(XedwList *));
-  for(i=0; i< max; i++) {
+      /* Change contents of AppManager to that of the new selection*/
+      old_list = appselections[appman_selection]->list;
+      max = appselections[appman_selection]->number;
+      list = (XedwList **) XtMalloc((max+1) * sizeof(XedwList *));
+      for(i=0; i< max; i++) {
 	  list[i] = (XedwList *) XtMalloc( sizeof(XedwList));
 	  list[i]->icon = old_list[i]->icon;
 	  list[i]->mask = old_list[i]->mask;
 	  list[i]->string = old_list[i]->string;
+      }
+      list[i] = NULL;
+      XedwListChange(appManager, list, max, 0, True);
   }
-  list[i] = NULL;
-  XedwListChange(appManager, list, max, 0, True);
 
   /* Reset scrollbar to top */
   setscroll(appManagerView, 0.0);
@@ -1438,10 +1450,10 @@ public int execute(fullname, filename, fullcmd, cwait, node)
 	       * so we can change the group of the terminal.
 	       */
 #ifdef USE_TERMIOS
-	      setpgrp(0, tcgetpgrp(0));
+	      setpgid(0, tcgetpgrp(0));
 #else /* termio */
 	      ioctl(0, TIOCGPGRP, &pgrp);
-	      setpgrp(0, pgrp);
+	      setpgid(0, pgrp);
 #endif
 	      
 	      /*
@@ -1456,7 +1468,7 @@ public int execute(fullname, filename, fullcmd, cwait, node)
 #else /* termio */
 	      ioctl(0, TIOCSPGRP, &pid);
 #endif
-	      setpgrp(0, pid);
+	      setpgid(0, pid);
 	  }
 	  else
 	  {
@@ -1604,7 +1616,8 @@ SelOptions options;
     if ((list->xedwList_index == XDTM_LIST_NONE) && 
 	(options != A_SEL) && (options != IGNORE_SEL)) {
       /* MSEL and no files selected... */
-      alert_dialog("This program requires files", "to be selected", "Cancel");
+      if (!app_data.silentsel) 
+	alert_dialog("This program requires files", "to be selected", "Cancel");
       newprogram = NULL;
     } else {
       while (list != NULL) {
@@ -1618,7 +1631,7 @@ SelOptions options;
 	list = list->next;
 	number++;
       }
-      if (options == O_SEL && number != 1) {
+      if (options == O_SEL && number != 1 && !app_data.silentsel) {
 	alert_dialog("This program requires only",
 		     "one file selected", "Cancel");
 	newprogram = NULL;
@@ -1643,7 +1656,7 @@ SelOptions options;
       XtFree((char *)arguments);
     }
   } else {
-    if (list->xedwList_index != XDTM_LIST_NONE) {
+    if (list->xedwList_index != XDTM_LIST_NONE && !app_data.silentsel ) {
       alert_dialog("This program does not require",
 		   "any files to be selected", "Cancel");
       newprogram = NULL;
@@ -1841,9 +1854,11 @@ public void child_died()
   fflush(stderr);
 #endif
 
-#ifdef TRUE_SYSV
+#if defined(TRUE_SYSV)
   /* I shall assume that ALL SYSV OS's without BSD do NOT have wait3 */
   pid = wait(&status);
+#elif defined(SVR4)            /* SVR4 definitely has waitpid() */
+  pid = waitpid((pid_t)-1, &status, WNOHANG);
 #else
   pid = wait3(&status, WNOHANG, 0);
 #endif
@@ -1932,13 +1947,54 @@ char *programname;
   }
 }
 
+/*****************************************************************************
+ *                             checkMissedPid                             *
+ *****************************************************************************/
+private void checkMissedPid()
+{
+  /* handle pid of child terminated before they are 
+    registered by parent */
+  extern Cursor left_ptr;
+  int i, count = 0;
+
+#ifdef DEBUG
+fprintf(stderr, "Entering checkMissedPid\n");
+#endif
+
+  for (i = 0; i < maxPids; i++) {
+    if (missedPid[i] == 0) {
+      count++;
+    } else if (decrement_counter(missedPid[i]) == True) {
+      missedPid[i] = 0;
+      count++;
+    }
+  }
+
+  if (count == maxPids) {
+    /* no more pid to clear, reset clock alarm,
+      proclist and cursor */
+    alarm(0);
+    refresh_proclist();
+    setCursor(left_ptr);
+#ifdef DEBUG
+fprintf(stderr, "Exiting checkMissedPid, no more pid uncleared\n");
+#endif
+  }
+#ifdef DEBUG
+  else
+fprintf(stderr, "Exiting checkMissedPid, still %d pid uncleared\n", maxPids - count);
+#endif
+}
+
+      
 /*****************************************************************************
  *                             decrement_counter                             *
  *****************************************************************************/
-private void decrement_counter(pid)
+private Boolean decrement_counter(pid)
 int pid;
 {
   ProcessList *ptr, *ptr2;
+  int i, index = -1;
 
 #ifdef DEBUG
   fprintf(stderr,"#################################\n");
@@ -1977,8 +2033,30 @@ int pid;
       ptr2 = ptr2->next;
     }
     if (!ptr2) {
-      fprintf(stderr,
-	      "decrement_counter: List traversal error.  Item not found.\n");
+      for (i=0; i < maxPids; i++) 
+	if (missedPid[i] == 0) {
+	  if (index == -1) {
+	    missedPid[i] = pid;
+	    index = i;
+	  }
+	} else if (missedPid[i] == pid) {
+	  if (index != -1) {
+	    missedPid[index] = 0;
+	  }
+	  index = i;
+	  break;
+	}
+	    
+
+      if ((index == -1) && (i == maxPids))
+	fprintf(stderr, "out of space in missed pid table\n");
+      else {
+	signal(SIGALRM, checkMissedPid);
+	alarm(1);
+	return False;
+      }
+      /*      fprintf(stderr,
+	      "decrement_counter: List traversal error.  Item not found.\n"); */
     } else {
 #ifdef DEBUG
       fprintf(stderr,
@@ -2001,6 +2079,8 @@ int pid;
   fprintf(stderr,"#################################\n");
   fflush(stderr);
 #endif
+
+  return True;
 }
 
 /*****************************************************************************
@@ -2023,8 +2103,8 @@ private void refresh_proclist()
   private Widget listprocmenu;
   private Boolean firsttime = True;
   ProcessList *ptr;
-  char tmpstring[80];
-  Cardinal num, n, i;
+  char *tmpstring;
+  Cardinal num, n, i, len;
 
 #ifdef DEBUG
   fprintf(stderr,"refresh_proclist: Entering\n");
@@ -2073,16 +2153,19 @@ private void refresh_proclist()
 
     proclist[i] = XtNew(XedwList);
     proclist[i]->string = XtMalloc(80);
+    sprintf(proclist[i]->string, "%d: ", ptr->pid);
+    len = strlen(proclist[i]->string);
+    tmpstring = ptr->node->string;
     if (ptr->node->options == IGNORE_SEL) {
       /* We've got a dirman node.  Let's only show the
 	 name of the executable, not the path. */
-      char *c;
-      c = ptr->node->string;
-      while (*c++);
-      while (*c != '/') c--;
-      sprintf(tmpstring, "%d : %s", ptr->pid, ++c);
-    } else sprintf(tmpstring, "%d : %s", ptr->pid, ptr->node->string);
-    strncpy(proclist[i]->string, tmpstring,80);
+      while (*tmpstring++);
+      while (*tmpstring != '/') tmpstring--;
+      tmpstring++;
+    }
+    strncpy(proclist[i]->string+len, tmpstring,
+	    80 - len);
+    proclist[i]->string[79] = 0;
 
 #ifdef DEBUG
     fprintf(stderr, "                  proclist[%d]->string = %s\n",
@@ -2167,11 +2250,15 @@ void process_list_done(w, client_data, call_data)
 /*****************************************************************************
  *                                  plistcmp                                 *
  *****************************************************************************/
+#if NeedFunctionPrototypes
+private int plistcmp(const void *p1, const void *p2)
+#else
 private int plistcmp(p1, p2)
-XedwList **p1;
-XedwList **p2;
+void *p1;
+void *p2;
+#endif
 {
-  return(strcmp((*p1)->string, (*p2)->string));
+  return(strcmp((*(XedwList **)p1)->string, (*(XedwList **)p2)->string));
 }
 
 /*****************************************************************************
