@@ -51,7 +51,7 @@
   public String getfilename(String);
   extern Boolean getIconType(String, String, XdtmList*);
   private void GoUp(Widget, XButtonEvent*);
-  private int iconcmp(XdtmList**, XdtmList**);
+  private int iconcmp(const void *, const void *);
   extern void PopMenu(Widget, XButtonEvent*);
   private void Refresh(Widget, XButtonEvent*);
   private void SelectAll(Widget, XButtonEvent*);
@@ -237,44 +237,66 @@ String newpath;
     /* Get icon type for each file */
     i = 0;
     while ((dp = readdir(dirp)) != NULL) {
+	
+      String basename = NULL, path = NULL;
+
       if (i == icon_list_max_size) {
 	icon_list_max_size += LISTINCR;
 	icon_list = (XdtmList**) XtRealloc((char *)icon_list,
 					   sizeof(XdtmList*) * 
 					   icon_list_max_size);
-      } else 
-	if (getIconType(dp->d_name, newpath, &temp)) {
-	  icon_list[i] = XtNew(XdtmList);
-	  icon_list[i]->string    = temp.string;
-	  icon_list[i]->isdir  = temp.isdir;
+      }
+	
+      if (((strcmp(dp->d_name, ".") == 0) &&
+	   (app_data.usedotspec == False)) ||
+	  ((strcmp(dp->d_name, "..") == 0) &&
+	   (app_data.usedotdotspec == False))) {
 
-	  if (strcmp(dp->d_name, ".") == 0) { /* this control should be done
-						 in getIconType function just
-						 before call to doIconPrefs*/
-		String basename = NULL, path = NULL;
+	splitPath(newpath, &basename, &path);
+	if (strcmp(dp->d_name, "..") == 0) {
+	  String tmppath = path;
+
+	  XtFree(basename);
+	  splitPath(tmppath, &basename, &path);
+	  XtFree(tmppath);
+        }
+      } else {
+	  basename = XtNewString(dp->d_name);
+	  path = XtNewString(newpath);
+      }
+      
+      if (getIconType(basename, path, &temp)) {
+	icon_list[i] = XtNew(XdtmList);
+
+	if (strcmp(dp->d_name, basename) != 0) {
+	  /* This is either . or .. without their spec
+	     replace basename by dp->d_name in temp.string */
+	  int l, lbase = strlen(basename), ltemp = strlen(temp.string);
+	  String ptr;
+
+	  /* in any case (icons, short or long listing) basename is
+	     always last in string, point at it */
+          ptr = temp.string + (ltemp - lbase);
+
+	  /* copy dp->d_name at ptr */
+	  strcpy(ptr, dp->d_name);
+
+	  /* adjust string length */
+	  if ((l = strlen(dp->d_name) - lbase) != 0)
+	    temp.string = XtRealloc(temp.string, ltemp + l + 1);
+        }
+
+	icon_list[i]->string    = temp.string;
+	icon_list[i]->isdir     = temp.isdir;
+	icon_list[i]->icon      = temp.icon;
+	icon_list[i]->mask      = temp.mask;
+	icon_list[i]->user_data = temp.user_data;
+	i++;
+      }
+      
+      XtFree(basename);
+      XtFree(path);
 
-		if (app_data.usedoticon == True) {
-		  icon_list[i]->icon = temp.icon;
-		  icon_list[i]->mask = temp.mask;
-	        }
-		splitPath(newpath, &basename, &path);
-		if (getIconType(basename, path, &temp))	{
-		    if (app_data.usedoticon == False) {
-		      icon_list[i]->icon = temp.icon;
-		      icon_list[i]->mask = temp.mask;
-		    }
-		    icon_list[i]->user_data = temp.user_data;
-		    XtFree(temp.string);
-		    XtFree(basename);
-		    XtFree(path);
-		}
-	    } else {
-		icon_list[i]->icon      = temp.icon;
-		icon_list[i]->mask      = temp.mask;
-		icon_list[i]->user_data = temp.user_data;
-	    }
-	  i++;
-	}
     }
     icon_list[i] = NULL;	/* NULL terminated */
     icon_list_size = i;
@@ -311,10 +333,18 @@ String newpath;
 /*****************************************************************************
  *                                iconcmp                                    *
  *****************************************************************************/
-private int iconcmp(ip1, ip2)
-XdtmList **ip1, **ip2;
+#if NeedFunctionPrototypes
+private int iconcmp(const void *p1, const void *p2)
+#else
+private int iconcmp(p1, p2)
+void *p1;
+void *p2;
+#endif
 {
-  /* compare the strings of 2 XedwList's
+  XdtmList **ip1 = (XdtmList **)p1;
+  XdtmList **ip2 = (XdtmList **)p2;
+
+  /* compare the strings of 2 XdtmList's
    * If isdir=True then put in front, otherwise put in order 
    */
     if (app_data.dirfirst == True)
@@ -618,8 +648,12 @@ XButtonEvent *event;
 /*****************************************************************************
  *                               changestate                                 *
  *****************************************************************************/
+#if NeedFunctionPrototypes
+public void changestate(Boolean new_state)
+#else
 public void changestate(new_state)
 Boolean new_state;
+#endif
 {
   /* Toggle the sensitivity of all the widgets which may not be used
    * when no files are highlighted.
