@@ -38,7 +38,6 @@
 #include <sys/param.h>
 #include <pwd.h>
 #include <unistd.h> /* for R_OK */
-#include <grp.h>
 #ifdef alliant
 #include <a.out.h>            /* Alliant FX series magic number file */
 #endif
@@ -382,7 +381,7 @@ Widget top;
    */
   toplevel = top;
   Fileinfolist = NULL;
-};
+}
 
 /*****************************************************************************
  *                               create_doubleclick                          *
@@ -1589,15 +1588,20 @@ String filename, path;
   if (stat(current->dc_fullname, &(current->filestat)) == -1) {
     fprintf(stderr, "File status unreadable!\n");
   } else {
+      struct passwd *pw;
+      struct group *grp;
+      
 
     /* Save the initial stat information for undo */
 
     current->oldstat.mode = current->laststat.mode = current->filestat.st_mode;
 
     /* Load the name of the owner of the file into the owner text widget */
+    if ((pw = (struct passwd*)getpwuid(current->filestat.st_uid)) != NULL)
+      strcpy(current->edit_owner, pw->pw_name);
+    else sprintf(current->edit_owner, "%d",
+		 (short)current->filestat.st_uid);
 
-    strcpy(current->edit_owner,
-	   ((struct passwd *) getpwuid(current->filestat.st_uid))->pw_name);
 
     XtVaSetValues(
         current->form1c_text_owner,
@@ -1605,9 +1609,11 @@ String filename, path;
 	    NULL ) ;
 
     /* Load the name of the group of the file into the group text widget */
+    if ((grp = (struct group*)getgrgid(current->filestat.st_gid)) != NULL)
+      strcpy(current->edit_group, grp->gr_name);
+    else sprintf(current->edit_group, "%d",
+		 (short)current->filestat.st_gid);
 
-    strcpy(current->edit_group,
-	   ((struct group *) getgrgid(current->filestat.st_gid))->gr_name);
 
     XtVaSetValues(
         current->form1c_text_group,
@@ -2477,7 +2483,7 @@ int errnum;
 	alert_dialog("No space to create file", NULL, NULL);
       break;
 
-#ifndef TRUE_SYSV
+#ifdef EDQUOT
       case EDQUOT:
 	alert_dialog("Quota over limit", NULL, NULL);
       break;
@@ -2818,7 +2824,8 @@ XtPointer call_data;
   }
 
   if (strcmp(current->edit_owner, current->laststat.owner))
-    if (!(pass=(getpwnam(current->edit_owner)))) {
+    if (!(pass=(getpwnam(current->edit_owner))) &&
+	!(pass=(getpwuid((uid_t)atoi(current->edit_owner))))) {
       alert_dialog("No such user", current->edit_owner, NULL);
       strcpy(current->edit_owner, current->laststat.owner);
       load_text(current->form1c_text_owner, current->edit_owner);
@@ -3009,10 +3016,10 @@ Widget w;
 XtPointer client_data;
 XtPointer call_data;
 {
-    if (access(SYSTEM_HELP_PERM, R_OK) == 0)
-      displayfile(SYSTEM_HELP_PERM, NULL, "xdtm permissions help", XtGrabNone);
+    if (access(perm_help_file, R_OK) == 0)
+      displayfile(perm_help_file, NULL, "xdtm permissions help", XtGrabNone);
     else
-      alert_dialog("Help file not found at", SYSTEM_HELP_PERM, "Cancel");
+      alert_dialog("Help file not found at", perm_help_file, "Cancel");
 }
 
 /*****************************************************************************
@@ -3024,9 +3031,8 @@ char *groupname;
   struct group *group;
 
   setgrent ();
-  group = getgrnam (groupname);
 
-  if (group == NULL)
+  if (!(group=getgrnam(groupname)) && !(group=getgrgid(atoi(groupname))))
     return (-1);
   else
     return (group->gr_gid);
@@ -3038,7 +3044,11 @@ char *groupname;
 int user_is_member( gid )
 gid_t gid ;
 {
+#ifdef SYSV
+  gid_t gidset[NGROUPS];
+#else
   int gidset[NGROUPS];
+#endif
   int ngroups, i;
 
   /* Get the list of groups that the user is in. */
