@@ -46,12 +46,20 @@ static MenuContents fileMenuStrings[] = {
   { "move",      "Move files",     Move,      noflag },
   { "trash",     "Delete files",   Trash,     noflag },
   {  LINE,        NULL,            0,         noflag },
+  { "reload",    "Reload config file", Reload, noflag},
+  {  LINE,        NULL,            0,         noflag },
   { "quit",      "Quit Program",   Quit,      noflag },
 };
 
 static MenuContents optionMenuStrings[] = {
-  { "dirfirst",   "Directories first",     Dirfirst,    flagged },
-  { "usedoticon", "Use Dot Icon",          Usedoticon,  flagged },
+  { "dirfirst",       "Directories first", Dirfirst,       flagged },
+#ifndef TRUE_SYSV
+  { "followsymlinks", "Follow Sym Links",  FollowSymLinks, flagged },
+#endif
+  { "usedotspec",     "Use . Spec",        Usedotspec,     flagged },
+  { "usedotdotspec",  "Use .. Spec",       Usedotdotspec,  flagged },
+  {  LINE,             NULL,               0,              flagged },
+  { "silentsel",      "Silent Selection",  Silentsel,      flagged },
 };
 
 static MenuContents viewMenuStrings[] = {
@@ -95,6 +103,7 @@ public Icon_mode current_mode;
   private void menuSelect(Widget, Cardinal, XtPointer);
   extern void newfile_dialog(Boolean, String, Boolean);
   extern void popup_process_list(void);
+  extern void loadConfig(void);
   extern void quit_dialog(void);
   extern void setCursor(Cursor);
 #else
@@ -110,6 +119,7 @@ public Icon_mode current_mode;
   private void menuSelect();
   extern void newfile_dialog();
   extern void popup_process_list();
+  extern void loadConfig();
   extern void quit_dialog();
   extern void setCursor();
 #endif
@@ -294,7 +304,12 @@ void (*function)();
 	      XtSetArg(arglist[i], XtNleftMargin, (tick_width*1.5)); i++;
 	      if ((entry.paneNumber == current_mode.mode) ||
 		  ((entry.paneNumber == Dirfirst) && app_data.dirfirst) ||
-		  ((entry.paneNumber == Usedoticon) && app_data.usedoticon))
+#ifndef TRUE_SYSV
+		  ((entry.paneNumber == FollowSymLinks) && app_data.followsymlinks) ||
+#endif
+		  ((entry.paneNumber == Usedotspec) && app_data.usedotspec) ||
+		  ((entry.paneNumber == Usedotdotspec) && app_data.usedotdotspec) ||
+		  ((entry.paneNumber == Silentsel) && app_data.silentsel))
 		{
 		  XtSetArg(arglist[i], XtNleftBitmap, tick); i++; 
 		}
@@ -359,14 +374,14 @@ XtPointer rubbish;
 	sprintf(level, "The X Desktop Manager Version %d.%d",
 		RELEASE, PATCHLEVEL);
 	alert_dialog(level, "bug-reports: rjs@pencom.com\n\
-or         : xdtm@simpolis.fr", NULL);
+or         : Lionel.Mallet@sophia.inria.fr", NULL);
       break ;
 
       case Help :        /* If help file is readable show it */
-	if (access(SYSTEM_HELP, R_OK) == 0) 
-	  displayfile(SYSTEM_HELP, NULL, "X Desktop Manager Help", XtGrabNone);
+	if (access(help_file, R_OK) == 0) 
+	  displayfile(help_file, NULL, "X Desktop Manager Help", XtGrabNone);
 	else
-	  alert_dialog("Help file not found at", SYSTEM_HELP, "Cancel");
+	  alert_dialog("Help file not found at", help_file, "Cancel");
       break ;
 
       case New :         /* Create a newfile */
@@ -459,6 +474,12 @@ or         : xdtm@simpolis.fr", NULL);
 	button_selected(w, paneNumber, 0);
       break;
 
+    case Reload:  /* Reload config file */
+        loadConfig();
+	directoryManagerNewDirectory(cwd);
+	selectionChange(w, 0, NULL);
+	break;
+
     case Quit:    /* Quit the program.. maybe */
 	if (app_data.confirmaction || process_list)
 	  quit_dialog();
@@ -474,13 +495,37 @@ or         : xdtm@simpolis.fr", NULL);
 	changestate(False);  /* implicitly deslecting dirman selections */
 	break;
 	
-    case Usedoticon: /* Change to usedoticon display option */
-	app_data.usedoticon = !app_data.usedoticon;
-	XtVaSetValues(w, XtNleftBitmap, (app_data.usedoticon ? tick : None),
+#ifndef TRUE_SYSV
+    case FollowSymLinks: /* Change to followsymlinks display option */
+	app_data.followsymlinks = !app_data.followsymlinks;
+	XtVaSetValues(w, XtNleftBitmap, (app_data.followsymlinks ? tick : None),
 		      NULL);
 	directoryManagerNewDirectory(cwd);
 	changestate(False);  /* implicitly deslecting dirman selections */
 	break;
+#endif 
+
+    case Usedotspec: /* Change to usedotspec display option */
+	app_data.usedotspec = !app_data.usedotspec;
+	XtVaSetValues(w, XtNleftBitmap, (app_data.usedotspec ? tick : None),
+		      NULL);
+	directoryManagerNewDirectory(cwd);
+	changestate(False);  /* implicitly deslecting dirman selections */
+	break;
+	
+    case Usedotdotspec: /* Change to usedotdotspec display option */
+	app_data.usedotdotspec = !app_data.usedotdotspec;
+	XtVaSetValues(w, XtNleftBitmap, (app_data.usedotdotspec ? tick : None),
+		      NULL);
+	directoryManagerNewDirectory(cwd);
+	changestate(False);  /* implicitly deslecting dirman selections */
+	break;
+	
+    case Silentsel: /* Chnge to silentsel appman option */
+	app_data.silentsel = !app_data.silentsel;
+	XtVaSetValues(w, XtNleftBitmap, (app_data.silentsel ? tick : None),
+		      NULL);
+	break;
 	
     case Icons:    /* Change to icon mode */
 	if (current_mode.mode != Icons)
