@@ -59,6 +59,7 @@ private BTree *grey_tree;
   private iconPrefs *do_iconprefs(iconPrefs*, String, String, struct stat*);
   private Pixmap grey_icon(Pixmap);
   private BTree *grey_search(Pixmap, Pixmap*, BTree*);
+  public void loadConfig(void);
   private void initBitmaps(Widget);
   extern typePrefs *newTypePref(void);
   extern void selectionChange(Widget, Cardinal, XtPointer);
@@ -71,6 +72,7 @@ private BTree *grey_tree;
   private iconPrefs *do_iconprefs();
   private Pixmap grey_icon();
   private BTree *grey_search();
+  public void loadConfig();
   private void initBitmaps();
   extern typePrefs *newTypePref();
   extern void selectionChange();
@@ -103,7 +105,7 @@ XdtmList *element;
   
   element->string = XtNewString(filename);
 
-  if (current_mode.mode == Short) element->icon = NULL;
+  if (current_mode.mode == Short) element->icon = (Pixmap)NULL;
   else {
     filestatus = (struct stat*) XtMalloc (sizeof(struct stat));
     fullname=(String) XtMalloc((strlen(filename)+strlen(path)+4) * 
@@ -136,7 +138,7 @@ XdtmList *element;
         }
       
 	/* try all rules in prefs */
-	if (pref && ((icon = pref->icon) != (Pixmap)NULL)) {/* should be
+	if (pref && ((icon = pref->icon) != None)) {/* should be
 						     if (pref && ((icon = ...
 						     to avoid forcing user to
 						     set deficon on ANY file */
@@ -196,8 +198,8 @@ XdtmList *element;
 	char cm = current_mode.options;
 	String output_line;
 
-	element->icon = (Pixmap)NULL;
-	element->mask = (Pixmap)NULL;
+	element->icon = None;
+	element->mask = None;
 	length = 0;
 	output_line = XtNewString("");
 	if (cm & PERMS) {
@@ -393,21 +395,50 @@ struct stat *filestatus;
     pref = applyprefs(tp->fifo, fullname, filename, filestatus);
   }
 
-#if defined(macII) || !defined(SYSV) || defined(SVR4_0)
-
+#if defined(macII) || !defined(TRUE_SYSV)
   /* Try Symbolic Links */
-  if (pref == NULL &&
-      tp->slink != NULL &&
-      insymlink == False &&
-      (filestatus->st_mode & S_IFMT) == S_IFLNK) {
-    insymlink = True;
-    newfilestatus = (struct stat*) XtMalloc (sizeof(struct stat));
-    if (stat(fullname, newfilestatus) != -1) {
-      pref = applyprefs(tp->slink, fullname, filename, newfilestatus);
-      XtFree((char *)newfilestatus);
+  if (app_data.followsymlinks == False) {
+    if (pref == NULL &&
+	tp->slink != NULL &&
+	insymlink == False &&
+	(filestatus->st_mode & S_IFMT) == S_IFLNK) {
+	insymlink = True;
+	newfilestatus = (struct stat*) XtMalloc (sizeof(struct stat));
+	if (stat(fullname, newfilestatus) != -1) {
+	    pref = applyprefs(tp->slink, fullname, filename, newfilestatus);
+	}
+	XtFree((char *)newfilestatus);
+	insymlink = False;
+    }
+
+  } else {
+    if (pref == NULL &&
+	(filestatus->st_mode & S_IFMT) == S_IFLNK) {
+	char lkfullname[MAXPATHLEN];
+	char *lkname;
+	int nbytes;
+	
+	newfilestatus = (struct stat*) XtMalloc (sizeof(struct stat));
+	if (stat(fullname, newfilestatus) != -1) {
+	    if ((nbytes = readlink(fullname, lkfullname, MAXPATHLEN)) >= 0) {
+	      lkfullname[nbytes] = 0;
+	      if ((lkname = strrchr(lkfullname, '/')) == NULL)
+		lkname = lkfullname;
+	      else lkname++;
+	      pref = applyprefs(tp, lkfullname, lkname, newfilestatus);
+	    } else if (tp->slink != NULL && insymlink == False) {
+		insymlink = True;
+		pref = applyprefs(tp->slink, fullname, filename, newfilestatus);
+		insymlink = False;
+	    }
+	    
+	}
+	XtFree((char *)newfilestatus);
     }
-    insymlink = False;
   }
+  
+      
+  
 
   /* Try Sockets */
   if (pref == NULL &&
@@ -482,21 +513,32 @@ BTree *tree;
   extern Widget topLevel;
 
   if (tree == NULL) {
+    int x, y;
+    unsigned int width, height, bw, depth;
+    Window root;
+
     /* Create Pixmap */
     result = (BTree*) XtMalloc (sizeof(BTree));
     result->icon = icon;
     result->left = NULL;
     result->right = NULL;
+
+    if (!XGetGeometry(XtDisplay(topLevel), icon, &root, &x, &y,
+		      &width, &height, &bw, &depth)) {
+	width = 32;
+	height = 32;
+	depth = DefaultDepthOfScreen(XtScreen(topLevel));
+    }
+    
     newpixmap = XCreatePixmap(XtDisplay(topLevel),
 			      RootWindowOfScreen(XtScreen(topLevel)), 
-			      32, 32,
-			      DefaultDepthOfScreen(XtScreen(topLevel)));
+			      width, height, depth);
     XSetFunction(XtDisplay(topLevel), xdtmgc, GXcopy);
-    XCopyPlane(XtDisplay(topLevel),
-	       icon, newpixmap, xdtmgc, 0, 0, 32, 32, 0, 0, 1);  
-    XSetFunction(XtDisplay(topLevel), xdtmgc, GXand);
-    XCopyPlane(XtDisplay(topLevel),
-	       grey_mask, newpixmap, xdtmgc, 0, 0, 32, 32, 0, 0, 1); 
+    XCopyArea(XtDisplay(topLevel), icon, newpixmap, xdtmgc,
+	      0, 0, width, height, 0, 0);
+    XFillRectangle(XtDisplay(topLevel), newpixmap, xdtmgc,
+		   0, 0, width, height);
+    
     result->grey = newpixmap; 
     *new = newpixmap;
   } else 
@@ -611,16 +653,11 @@ struct stat *filestatus;
 public Boolean parsePreferences(w)
 Widget w;
 {
-  /* Call the parser on the config file */
-
-  extern AppSelection **appselections;
-  extern Cardinal selectionindex;
+  /* locate config file then call parser on it */
   extern String home;
-  extern Widget selectionMenu;
 
-  MenuContents *selectionmenu;
   String setupfile;
-  Cardinal i;
+  String libsetupfile;
 
   initBitmaps(w);  /* Initialise default pixmaps */
 
@@ -629,19 +666,27 @@ Widget w;
    */
   
   setupfile = (String) XtMalloc ((strlen(home) + 10) * sizeof(char));
+  libsetupfile = (String) XtMalloc ((strlen(app_data.systemlibdir) + 10)
+				    * sizeof(char));
 
   user = geteuid();
   group = getegid();
 
   strcpy(setupfile, home);
   strcat(setupfile, "/.xdtmrc");
-  if (((app_data.cffile == 0 ||
-	((yyin = fopen(app_data.cffile, "r")) == NULL)) && /*try appdefaults*/
-       ((preferences_filename = app_data.cffile) == app_data.cffile))   && 
-      (((yyin = fopen(setupfile,        "r")) == NULL) &&  /*try home dir*/
-       ((preferences_filename = setupfile) == setupfile))               &&
-      (((yyin = fopen(SYSTEM_XDTMRC,    "r")) == NULL) &&  /*try system dir*/
-       ((preferences_filename = XtNewString(SYSTEM_XDTMRC)) != NULL)))
+  strcpy(libsetupfile, app_data.systemlibdir);
+  strcat(libsetupfile, "/xdtmrc");
+  
+  if ((app_data.cffile == 0 ||
+       (((preferences_filename = app_data.cffile) == app_data.cffile) && /*try appdefaults*/
+	((yyin = fopen(app_data.cffile, "r")) == NULL)))              &&
+      (((preferences_filename = setupfile) == setupfile) &&  /*try home dir*/
+       ((yyin = fopen(setupfile, "r")) == NULL))                      &&
+      ((strcmp(app_data.systemlibdir, SYSTEM_LIB_DIR) == 0) ||
+       (((preferences_filename = libsetupfile) == libsetupfile) &&  /*try system lib dir*/
+	((yyin = fopen(libsetupfile, "r")) == NULL)))                 &&
+      (((preferences_filename = XtNewString(SYSTEM_XDTMRC)) != NULL) &&  /*try system dir*/
+       ((yyin = fopen(SYSTEM_XDTMRC, "r")) == NULL)))
     {
       fprintf(stderr,
 	      "Error: No user or system xdtmrc found\n");
@@ -651,28 +696,78 @@ Widget w;
 	      "       command line using the -cf option\n");
       exit(2);
     } else {
-      /* parse the file */
-      if (yyparse()) {
-	fprintf(stderr, "Error parse failed. exiting\n");
-	exit(1);
-      }
+
+      loadConfig();
     }
+
   XtFree((char *)setupfile);
-  
-  /* Create selection menu */
-  selectionmenu = (MenuContents*) XtMalloc (sizeof(MenuContents) *
-					    selectionindex);
-  for(i = 0; i < selectionindex; i++) {
-    selectionmenu[i].paneName   = appselections[i]->name;
-    selectionmenu[i].paneLabel  = appselections[i]->name;
-    selectionmenu[i].paneNumber = i;
-    selectionmenu[i].set        = noflag;
-  }
-  createMenu(selectionMenu, selectionmenu, i, selectionChange);
+  XtFree((char *)libsetupfile);
 
   return True;
 }
 
+/*****************************************************************************
+ *                             loadConfig                              *
+ *****************************************************************************/
+public void loadConfig()
+{
+  /* Call the parser on the config file */
+
+  extern AppSelection **appselections;
+  extern Cardinal selectionindex;
+  extern Widget selectionMenu;
+
+  static MenuContents *selectionmenu;
+  static Boolean firstTime = True;
+  Cardinal i;
+
+  /* first try to reopen the file if not called for 
+     the first time */
+  if (firstTime == False) {
+    yyin = freopen(preferences_filename, "r", yyin);
+  }
+
+  if (yyin != NULL) {
+    if (firstTime == False) {
+      /* free existing structs */
+      for(i = 0; i < selectionindex; i++) {
+	XtDestroyWidget(XtNameToWidget(selectionMenu, 
+				       selectionmenu[i].paneName));
+      }
+
+      XtFree((char *)selectionmenu);
+      selectionmenu = (MenuContents *) NULL;
+
+      for(i = 0; i < selectionindex; i++) 
+	freeAppSelection(appselections[i]);
+      appselections = (AppSelection **) NULL;
+
+      freeTypePref(prefs);
+      prefs = (typePrefs *) NULL;
+
+    } else {
+      firstTime = False;
+    }
+
+   /* parse the file */
+    if (yyparse()) {
+      fprintf(stderr, "Error parse failed. exiting\n");
+      exit(1);
+    }
+    
+    /* Create selection menu */
+    selectionmenu = (MenuContents*) XtMalloc (sizeof(MenuContents) *
+					      selectionindex);
+    for(i = 0; i < selectionindex; i++) {
+      selectionmenu[i].paneName   = appselections[i]->name;
+      selectionmenu[i].paneLabel  = appselections[i]->name;
+      selectionmenu[i].paneNumber = i;
+      selectionmenu[i].set        = noflag;
+    }
+    createMenu(selectionMenu, selectionmenu, i, selectionChange);
+  }
+}
+
 /*****************************************************************************
  *                               initBitmaps                                 *
  *****************************************************************************/
@@ -682,30 +777,43 @@ Widget w;
   /* Get default icon pixmaps + the stippled pixmap for greying icons */
 
   XGCValues values;
-
-  foldericon  = XCreateBitmapFromData(	XtDisplay(w),
+  Pixel fg, bg;
+  
+  fg = BlackPixelOfScreen(XtScreen(w));
+  bg = WhitePixelOfScreen(XtScreen(w));
+  
+  foldericon  = XCreatePixmapFromBitmapData(	XtDisplay(w),
 				      	RootWindowOfScreen(XtScreen(w)),
 				      	folder_bits,
-				     	IconBitmapWidth, IconBitmapHeight);
-  fileicon    = XCreateBitmapFromData(  XtDisplay(w),
+				     	IconBitmapWidth, IconBitmapHeight,
+					fg, bg,
+					DefaultDepthOfScreen(XtScreen(w)));
+  fileicon    = XCreatePixmapFromBitmapData(  XtDisplay(w),
                                       	RootWindowOfScreen(XtScreen(w)),
 				      	file_bits,
-				      	IconBitmapWidth, IconBitmapHeight);
+				      	IconBitmapWidth, IconBitmapHeight,
+					fg, bg,
+					DefaultDepthOfScreen(XtScreen(w)));
   grey_mask   = XCreateBitmapFromData(  XtDisplay(w),
                                       	RootWindowOfScreen(XtScreen(w)),
 				      	Grey_bits,
 				      	IconBitmapWidth, IconBitmapHeight);
   
-  /* GC for copying pixmaps */
+  /* GC for greying pixmaps */
   if ((BlackPixelOfScreen(XtScreen(w))) == 1) {
-    values.background = WhitePixelOfScreen(XtScreen(w));
-    values.foreground = BlackPixelOfScreen(XtScreen(w));
-  } else {
     values.background = BlackPixelOfScreen(XtScreen(w));
     values.foreground = WhitePixelOfScreen(XtScreen(w));
+  } else {
+    values.background = WhitePixelOfScreen(XtScreen(w));
+    values.foreground = BlackPixelOfScreen(XtScreen(w));
   }
 
-  xdtmgc = XtGetGC(w, (unsigned) GCBackground | GCForeground, &values);
+  values.stipple = grey_mask;
+  
+  xdtmgc = XtGetGC(w, (unsigned) GCBackground | GCForeground | GCStipple,
+		   &values);
+  XSetFillStyle(XtDisplay(w), xdtmgc, FillStippled);
+  
 		 
   grey_tree = NULL;
 }
